package com.ebei.screen.common.aspect;

import com.ebei.screen.common.exception.MyException;
import lombok.extern.slf4j.Slf4j;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Configuration;

/**
 * Redis切面处理类
 *
 * @author Levi
 */
@Slf4j
@Aspect
@Configuration
public class RedisAspect {
    @Value("${spring.redis.open}")
    private boolean open;

    @Around("execution(* com.ebei.screen.common.util.RedisUtils.*(..))")
    public Object around(ProceedingJoinPoint point) throws Throwable {
        Object result = null;
        if (open) {
            try {
                result = point.proceed();
            } catch (Exception e) {
                log.error("redis error", e);
                throw new MyException("Redis服务异常");
            }
        }
        return result;
    }
}
